EGE Game

Des informations confidentielles indiquent qu'un régime autoritaire, en place depuis des élections contestées, utilise des systèmes informatiques dans le but de diffuser une idéologie dangereuse. Votre mission est d'infiltrer ces réseaux et de compromettre les systèmes adverses. Vous progresserez d'une machine basique vers des systèmes ultra protégés, pivoterez entre divers réseaux afin de pirater des ordinateurs intermédiaires et attaquerez finalement l'intelligence artificielle stratégique qui contrôle l'exécutif.

Chaque niveau vous précisera l'OS (Operating System - Système d'exploitation) sur lequel vous opérerez et fournira des indices visant à déduire l'adresse IP ou le nom de la cible ainsi que les paramètres requis. Pour vous aider, tapez `help` afin d'afficher la liste des commandes disponibles, ou `man <commande>` pour obtenir une description détaillée des commandes qui, dans la réalité, font partie de l'arsenal à la disposition de tous les hackers. N'oubliez pas : le hacking est l'art d'exploiter les exceptions d'un système, pour le comprendre, le réparer et parfois l'empêcher de nuire. Le piratage c'est le commerce qui vise à en tirer un avantage personnel. Ne piratez rien, mais hackez tout; Hack the planet.

Cliquez sur « Lancer l'opération » pour débuter.

##

## Accès obtenu – Système de l'Exécutif

Vous avez infiltré le réseau ultra protégé et compromis l'intelligence artificielle stratégique qui contrôle l'exécutif. Grâce à vos compétences, les contre-mesures adverses ont été désactivées et des données critiques extraites, rétablissant ainsi l'ordre et la paix. Votre action a permis de neutraliser la menace et vous êtes décoré pour votre bravoure.

    ▗▄▄▄▖ ▗▄▄▖▗▄▄▄▖     ▗▄▄▖▗▞▀▜▌▄▄▄▄  ▗▞▀▚▖
    ▐▌   ▐▌   ▐▌       ▐▌   ▝▚▄▟▌█ █ █ ▐▛▀▀▘
    ▐▛▀▀▘▐▌▝▜▌▐▛▀▀▘    ▐▌▝▜▌     █   █ ▝▚▄▄▖
    ▐▙▄▄▖▝▚▄▞▘▐▙▄▄▖    ▝▚▄▞▘